pub enum Error {
InvalidUuid,
InvalidUsername,
Transport(Transport),
MojangAPIError,
}Expand description
This library’s own error enum, which is returned by every function that returns a Result.
Variants
InvalidUuid
An error that signifies that the user has provided an invalid UUID, be it in the wrong format or a non-existent UUID if in an online context.
InvalidUsername
An error that signifies that the user has provided an invalid username to Mojang’s API.
Transport(Transport)
A Transport error from ureq.
MojangAPIError
An error that signifies that the Mojang API returned an unexpected result.